CCL: /home/chisarie/Documents/lsst_ccl/CCL/include/ccl_massfunc.h File Reference

CCL

Functions
ccl_massfunc.h File Reference
`#include "ccl_core.h"`

Go to the source code of this file.

## Functions
void | ccl_cosmology_compute_sigma (ccl_cosmology *cosmo, int *status)
void | ccl_cosmology_compute_hmfparams (ccl_cosmology *cosmo, int *status)
double | ccl_massfunc (ccl_cosmology *cosmo, double smooth_mass, double a, double odelta, int *status)
double | ccl_halo_bias (ccl_cosmology *cosmo, double smooth_mass, double a, double odelta, int *status)
double | ccl_massfunc_m2r (ccl_cosmology *cosmo, double smooth_mass, int *status)
double | ccl_sigmaM (ccl_cosmology *cosmo, double smooth_mass, double a, int *status)

## Function Documentation

## ◆ ccl_cosmology_compute_hmfparams()

void ccl_cosmology_compute_hmfparams | ( | ccl_cosmology * | cosmo,
|  | int * | status
| ) |  |

Updates Tinker mass function fitting formulas for specific Delta

Parameters

  cosmo | Cosmological parameters
  status | Status flag. 0 if there are no errors, nonzero otherwise. For specific cases see documentation for ccl_error.

## ◆ ccl_cosmology_compute_sigma()

void ccl_cosmology_compute_sigma | ( | ccl_cosmology * | cosmo,
|  | int * | status
| ) |  |

Computes sigma(R), the power spectrum normalization, over log-spaced values of mass and radii The result is attached to the cosmology object

Parameters

  cosmo | Cosmological parameters
  status | Status flag. 0 if there are no errors, nonzero otherwise. For specific cases see documentation for ccl_error.

## ◆ ccl_halo_bias()

double ccl_halo_bias | ( | ccl_cosmology * | cosmo,
|  | double | smooth_mass,
|  | double | a,
|  | double | odelta,
|  | int * | status
| ) |  |

Compute the linear halo bias for a cosmology and mass scale

Parameters

  cosmo | Cosmological parameters
  smooth_mass | Mass to compute at, in units of Msun
  a | Scale factor, normalized to a=1 today
  status | Status flag. 0 if there are no errors, nonzero otherwise. For specific cases see documentation for ccl_error.

Returns
  hb, the halo bias at the specified parameters

## ◆ ccl_massfunc()

double ccl_massfunc | ( | ccl_cosmology * | cosmo,
|  | double | smooth_mass,
|  | double | a,
|  | double | odelta,
|  | int * | status
| ) |  |

Compute halo mass function at a given mass for a given cosmology as dn/ dlog10(M)

Parameters

  cosmo | Cosmological parameters
  smooth_mass | Mass to compute at, in units of Msun
  a | Scale factor, normalized to a=1 today
  odelta | choice of Delta
  status | Status flag. 0 if there are no errors, nonzero otherwise. For specific cases see documentation for ccl_error.

Returns
  massfunc, the value of the mass function at the specified parameters

## ◆ ccl_massfunc_m2r()

double ccl_massfunc_m2r | ( | ccl_cosmology * | cosmo,
|  | double | smooth_mass,
|  | int * | status
| ) |  |

Convert smoothing halo mass in units of Msun to smoothing halo radius in units of Mpc.

Parameters

  cosmo | Cosmological parameters
  smooth_mass | Mass to compute at, in units of Msun
  a | Scale factor, normalized to a=1 today
  odelta | choice of Delta
  status | Status flag. 0 if there are no errors, nonzero otherwise. For specific cases see documentation for ccl_error.

Returns
  smooth_radius, the equivalent tophat smoothing radius corresponding to smooth_mass

## ◆ ccl_sigmaM()

double ccl_sigmaM | ( | ccl_cosmology * | cosmo,
|  | double | smooth_mass,
|  | double | a,
|  | int * | status
| ) |  |

Calculate the standard deviation of density at smoothing mass M via interpolation. Return sigma from the sigmaM interpolation. Also computes the sigma interpolation if necessary.

Parameters

  cosmo | Cosmological parameters
  smooth_mass | Mass to compute at, in units of Msun
  a | Scale factor, normalized to a=1 today
  status | Status flag. 0 if there are no errors, nonzero otherwise. For specific cases see documentation for ccl_error.

Returns
  sigmaM, the standard deviation of density at mass scale M